@@ -77,7 +77,7 @@ sub set {
 	my $value = shift;
 
 	if(ref($value)) {
-		die __PACKAGE__."#set: arg[1] is a Ref. [$value] (第1引数がリファレンスです)\n";
+		die __PACKAGE__."#set: arg[1] is a reference. [$value] (第1引数がリファレンスです)\n";
 	}
 
 	$this->{value} = $value;
@@ -200,7 +200,7 @@ sub getRegexp {
 	if(!defined($type)) {
 		die __PACKAGE__."#getRegexp: arg[1] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($type)) {
-		die __PACKAGE__."#getRegexp: arg[1] is a Ref. [$type] (第1引数がリファレンスです)\n";
+		die __PACKAGE__."#getRegexp: arg[1] is a reference. [$type] (第1引数がリファレンスです)\n";
 	}
 
 	my $regexp;
@@ -215,7 +215,7 @@ sub getRegexp {
 	} elsif($type eq 'numberwide') {
 		$regexp = $re_widenum;
 	} else {
-		die __PACKAGE__."#getRegexp: arg[1] is no match. [$type] (指定された正規表現は存在しません)\n";
+		die __PACKAGE__."#getRegexp: arg[1] is an invalid type. [$type] (指定された正規表現は存在しません)\n";
 	}
 	
 	$regexp;
@@ -818,7 +818,7 @@ sub forceMin {
 	if(!defined($min)) {
 		die __PACKAGE__."#forceMin: arg[1] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($min)) {
-		die __PACKAGE__."#forceMin: arg[1] is a Ref. [$min] (第1引数がリファレンスです)\n";
+		die __PACKAGE__."#forceMin: arg[1] is a reference. [$min] (第1引数がリファレンスです)\n";
 	}
 
 	$this->forceNumber;
@@ -841,7 +841,7 @@ sub forceMax {
 	if(!defined($max)) {
 		die __PACKAGE__."#forceMax: arg[1] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($max)) {
-		die __PACKAGE__."#forceMax: arg[1] is a Ref. [$max] (第1引数がリファレンスです)\n";
+		die __PACKAGE__."#forceMax: arg[1] is a reference. [$max] (第1引数がリファレンスです)\n";
 	}
 
 	$this->forceNumber;
@@ -1087,13 +1087,13 @@ sub genRandomString {
 	if(!defined($length)) {
 		die __PACKAGE__."#genRandomString: arg[1] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($length)) {
-		die __PACKAGE__."#genRandomString: arg[1] is a Ref. [$length] (第1引数がリファレンスです)\n";
+		die __PACKAGE__."#genRandomString: arg[1] is a reference. [$length] (第1引数がリファレンスです)\n";
 	}
 
 	if(!defined($type)) {
 		$type = ['std'];
 	} elsif(ref($type) ne 'ARRAY') {
-		die __PACKAGE__."#genRandomString: arg[2] is not ARRAY ref. (第2引数が配列のリファレンスではありません)\n";
+		die __PACKAGE__."#genRandomString: arg[2] is not an ARRAY Ref. (第2引数が配列のリファレンスではありません)\n";
 	}
 
 	my @str;
@@ -1113,7 +1113,7 @@ sub genRandomString {
 		} elsif($TL->newValue($key)->isCharLen(1,1)) {
 			push(@str,$key);
 		} else {
-			die __PACKAGE__."#genRandomString: arg[2] [$key] is not supported. (第2引数の $key はサポートされていません)\n";
+			die __PACKAGE__."#genRandomString: arg[2] [$key] is an invalid type. (第2引数の $key はサポートされていません)\n";
 		}
 	}
 	
